==> kadu_0.11.0.orig.tar.bz2: kadu-0.11.0/plugins/screenshot/translations/screenshot_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>@default</name>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select image format, which screenshots will be stored and sent in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force .jpg extension for JPEG format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshots quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-1 for autodetection, 0 for best file compression, 100 for best image quality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste [IMAGE] clause automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled, module will automatically paste ready to send [IMAGE] clause in chat window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshots directory path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshots filename prefix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable directory size control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled, module will check for shots directory size and warn you if it gets size specified below.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum directory size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Define, how many kbytes can shots take in the directory before module will warn you.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> kB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ScreenShot images size limit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenShot</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image size is bigger than maximal image size for this chat.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenShotSaver</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create direcotry %1 for storing screenshots!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t write file %1.
Access denied or other problem!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshot %1 has 0 size!
It should be bigger.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenshotAction</name>
    <message>
        <source>ScreenShot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Simple shot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>With chat window hidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window shot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenshotNotification</name>
    <message>
        <source>ScreenShot size limit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images size limit exceed: %1 KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenshotTaker</name>
    <message>
        <source>Drag icon to some window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenshotToolBox</name>
    <message>
        <source>0 KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu-0.12.2.tar.bz2: kadu-0.12.2/plugins/screenshot/translations/screenshot_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="en_US">
<context>
    <name>@default</name>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select image format, which screenshots will be stored and sent in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Force .jpg extension for JPEG format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Forces to use short .jpg extension for files in JPEG format. Some other instant messagers needs it.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshots quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>-1 for autodetection, 0 for best file compression, 100 for best image quality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste [IMAGE] clause automatically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled, module will automatically paste ready to send [IMAGE] clause in chat window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshots directory path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshots filename prefix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable directory size control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled, module will check for shots directory size and warn you if it gets size specified below.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum directory size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Define, how many kbytes can shots take in the directory before module will warn you.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> kB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ScreenShot images size limit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenShot</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image size is bigger than maximal image size for this chat.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenShotSaver</name>
    <message>
        <source>Kadu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to create direcotry %1 for storing screenshots!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can&apos;t write file %1.
Access denied or other problem!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Screenshot %1 has 0 size!
It should be bigger.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenshotAction</name>
    <message>
        <source>ScreenShot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Simple Shot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>With Chat Window Hidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenshotNotification</name>
    <message>
        <source>ScreenShot size limit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images size limit exceed: %1 KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenshotTaker</name>
    <message>
        <source>Drag this icon onto the desired window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window Shot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScreenshotToolBox</name>
    <message>
        <source>0 KiB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
